@@ -6,6 +6,7 @@ from chai import Chai
 
 from datetime import date, datetime, timedelta
 from dateutil import tz
+from dateutil.relativedelta import MO, TU, WE, TH, FR, SA, SU
 import simplejson as json
 import warnings
 import calendar
@@ -592,6 +593,48 @@ class ArrowShiftTests(Chai):
         assertEqual(arw.shift(seconds=1), arrow.Arrow(2013, 5, 5, 12, 30, 46))
         assertEqual(arw.shift(microseconds=1), arrow.Arrow(2013, 5, 5, 12, 30, 45, 1))
 
+        # Remember: Python's weekday 0 is Monday
+        assertEqual(arw.shift(weekday=0), arrow.Arrow(2013, 5, 6, 12, 30, 45))
+        assertEqual(arw.shift(weekday=1), arrow.Arrow(2013, 5, 7, 12, 30, 45))
+        assertEqual(arw.shift(weekday=2), arrow.Arrow(2013, 5, 8, 12, 30, 45))
+        assertEqual(arw.shift(weekday=3), arrow.Arrow(2013, 5, 9, 12, 30, 45))
+        assertEqual(arw.shift(weekday=4), arrow.Arrow(2013, 5, 10, 12, 30, 45))
+        assertEqual(arw.shift(weekday=5), arrow.Arrow(2013, 5, 11, 12, 30, 45))
+        assertEqual(arw.shift(weekday=6), arw)
+
+        with assertRaises(IndexError):
+            arw.shift(weekday=7)
+
+        # Use dateutil.relativedelta's convenient day instances
+        assertEqual(arw.shift(weekday=MO), arrow.Arrow(2013, 5, 6, 12, 30, 45))
+        assertEqual(arw.shift(weekday=MO(0)), arrow.Arrow(2013, 5, 6, 12, 30, 45))
+        assertEqual(arw.shift(weekday=MO(1)), arrow.Arrow(2013, 5, 6, 12, 30, 45))
+        assertEqual(arw.shift(weekday=MO(2)), arrow.Arrow(2013, 5, 13, 12, 30, 45))
+        assertEqual(arw.shift(weekday=TU), arrow.Arrow(2013, 5, 7, 12, 30, 45))
+        assertEqual(arw.shift(weekday=TU(0)), arrow.Arrow(2013, 5, 7, 12, 30, 45))
+        assertEqual(arw.shift(weekday=TU(1)), arrow.Arrow(2013, 5, 7, 12, 30, 45))
+        assertEqual(arw.shift(weekday=TU(2)), arrow.Arrow(2013, 5, 14, 12, 30, 45))
+        assertEqual(arw.shift(weekday=WE), arrow.Arrow(2013, 5, 8, 12, 30, 45))
+        assertEqual(arw.shift(weekday=WE(0)), arrow.Arrow(2013, 5, 8, 12, 30, 45))
+        assertEqual(arw.shift(weekday=WE(1)), arrow.Arrow(2013, 5, 8, 12, 30, 45))
+        assertEqual(arw.shift(weekday=WE(2)), arrow.Arrow(2013, 5, 15, 12, 30, 45))
+        assertEqual(arw.shift(weekday=TH), arrow.Arrow(2013, 5, 9, 12, 30, 45))
+        assertEqual(arw.shift(weekday=TH(0)), arrow.Arrow(2013, 5, 9, 12, 30, 45))
+        assertEqual(arw.shift(weekday=TH(1)), arrow.Arrow(2013, 5, 9, 12, 30, 45))
+        assertEqual(arw.shift(weekday=TH(2)), arrow.Arrow(2013, 5, 16, 12, 30, 45))
+        assertEqual(arw.shift(weekday=FR), arrow.Arrow(2013, 5, 10, 12, 30, 45))
+        assertEqual(arw.shift(weekday=FR(0)), arrow.Arrow(2013, 5, 10, 12, 30, 45))
+        assertEqual(arw.shift(weekday=FR(1)), arrow.Arrow(2013, 5, 10, 12, 30, 45))
+        assertEqual(arw.shift(weekday=FR(2)), arrow.Arrow(2013, 5, 17, 12, 30, 45))
+        assertEqual(arw.shift(weekday=SA), arrow.Arrow(2013, 5, 11, 12, 30, 45))
+        assertEqual(arw.shift(weekday=SA(0)), arrow.Arrow(2013, 5, 11, 12, 30, 45))
+        assertEqual(arw.shift(weekday=SA(1)), arrow.Arrow(2013, 5, 11, 12, 30, 45))
+        assertEqual(arw.shift(weekday=SA(2)), arrow.Arrow(2013, 5, 18, 12, 30, 45))
+        assertEqual(arw.shift(weekday=SU), arw)
+        assertEqual(arw.shift(weekday=SU(0)), arw)
+        assertEqual(arw.shift(weekday=SU(1)), arw)
+        assertEqual(arw.shift(weekday=SU(2)), arrow.Arrow(2013, 5, 12, 12, 30, 45))
+
     def test_shift_negative(self):
 
         arw = arrow.Arrow(2013, 5, 5, 12, 30, 45)
@@ -607,6 +650,27 @@ class ArrowShiftTests(Chai):
         assertEqual(arw.shift(seconds=-1), arrow.Arrow(2013, 5, 5, 12, 30, 44))
         assertEqual(arw.shift(microseconds=-1), arrow.Arrow(2013, 5, 5, 12, 30, 44, 999999))
 
+        # Not sure how practical these negative weekdays are
+        assertEqual(arw.shift(weekday=-1), arw.shift(weekday=SU))
+        assertEqual(arw.shift(weekday=-2), arw.shift(weekday=SA))
+        assertEqual(arw.shift(weekday=-3), arw.shift(weekday=FR))
+        assertEqual(arw.shift(weekday=-4), arw.shift(weekday=TH))
+        assertEqual(arw.shift(weekday=-5), arw.shift(weekday=WE))
+        assertEqual(arw.shift(weekday=-6), arw.shift(weekday=TU))
+        assertEqual(arw.shift(weekday=-7), arw.shift(weekday=MO))
+
+        with assertRaises(IndexError):
+            arw.shift(weekday=-8)
+
+        assertEqual(arw.shift(weekday=MO(-1)), arrow.Arrow(2013, 4, 29, 12, 30, 45))
+        assertEqual(arw.shift(weekday=TU(-1)), arrow.Arrow(2013, 4, 30, 12, 30, 45))
+        assertEqual(arw.shift(weekday=WE(-1)), arrow.Arrow(2013, 5, 1, 12, 30, 45))
+        assertEqual(arw.shift(weekday=TH(-1)), arrow.Arrow(2013, 5, 2, 12, 30, 45))
+        assertEqual(arw.shift(weekday=FR(-1)), arrow.Arrow(2013, 5, 3, 12, 30, 45))
+        assertEqual(arw.shift(weekday=SA(-1)), arrow.Arrow(2013, 5, 4, 12, 30, 45))
+        assertEqual(arw.shift(weekday=SU(-1)), arw)
+        assertEqual(arw.shift(weekday=SU(-2)), arrow.Arrow(2013, 4, 28, 12, 30, 45))
+
     def test_shift_quarters_bug(self):
 
         arw = arrow.Arrow(2013, 5, 5, 12, 30, 45)
@@ -923,6 +987,23 @@ class ArrowSpanRangeTests(Chai):
             assertEqual(f.tzinfo, tz.gettz('US/Central'))
             assertEqual(c.tzinfo, tz.gettz('US/Central'))
 
+class ArrowIntervalTests(Chai):
+
+    def test_incorrect_input(self):
+        correct = True
+        try:
+            result = arrow.Arrow.interval('month', datetime(2013, 1, 2), datetime(2013, 4, 15),0)
+        except:
+            correct = False
+
+        assertEqual(correct,False)
+
+    def test_correct(self):
+        result = arrow.Arrow.interval('hour', datetime(2013, 5, 5, 12, 30), datetime(2013, 5, 5, 17, 15),2)
+
+        assertEqual(result,[(arrow.Arrow(2013, 5, 5, 12), arrow.Arrow(2013, 5, 5, 13, 59, 59, 999999)),
+            (arrow.Arrow(2013, 5, 5, 14), arrow.Arrow(2013, 5, 5, 15, 59, 59, 999999)),
+            (arrow.Arrow(2013, 5, 5, 16), arrow.Arrow(2013, 5, 5, 17, 59, 59, 999999))])
 
 class ArrowSpanTests(Chai):
 
@@ -1034,6 +1115,60 @@ class ArrowHumanizeTests(Chai):
         self.datetime = datetime(2013, 1, 1)
         self.now = arrow.Arrow.utcnow()
 
+    def test_granularity(self):
+    
+        assertEqual(self.now.humanize(granularity = 'second'), 'just now')
+        
+        later1 = self.now.shift(seconds=1)
+        assertEqual(self.now.humanize(later1, granularity = 'second'), 'just now')
+        assertEqual(later1.humanize(self.now, granularity = 'second'), 'just now')
+        assertEqual(self.now.humanize(later1, granularity = 'minute'), '0 minutes ago')
+        assertEqual(later1.humanize(self.now, granularity = 'minute'), 'in 0 minutes')
+        
+        later100 = self.now.shift(seconds=100)
+        assertEqual(self.now.humanize(later100, granularity = 'second'), 'seconds ago')
+        assertEqual(later100.humanize(self.now, granularity = 'second'), 'in seconds')
+        assertEqual(self.now.humanize(later100, granularity = 'minute'), 'a minute ago')
+        assertEqual(later100.humanize(self.now, granularity = 'minute'), 'in a minute')
+        assertEqual(self.now.humanize(later100, granularity = 'hour'), '0 hours ago')
+        assertEqual(later100.humanize(self.now, granularity = 'hour'), 'in 0 hours')
+        
+        later4000 = self.now.shift(seconds=4000)
+        assertEqual(self.now.humanize(later4000, granularity = 'minute'), '66 minutes ago')
+        assertEqual(later4000.humanize(self.now, granularity = 'minute'), 'in 66 minutes')
+        assertEqual(self.now.humanize(later4000, granularity = 'hour'), 'an hour ago')
+        assertEqual(later4000.humanize(self.now, granularity = 'hour'), 'in an hour')
+        assertEqual(self.now.humanize(later4000, granularity = 'day'), '0 days ago')
+        assertEqual(later4000.humanize(self.now, granularity = 'day'), 'in 0 days')
+        
+        later105 = self.now.shift(seconds=10 ** 5)
+        assertEqual(self.now.humanize(later105, granularity = 'hour'), '27 hours ago')
+        assertEqual(later105.humanize(self.now, granularity = 'hour'), 'in 27 hours')
+        assertEqual(self.now.humanize(later105, granularity = 'day'), 'a day ago')
+        assertEqual(later105.humanize(self.now, granularity = 'day'), 'in a day')
+        assertEqual(self.now.humanize(later105, granularity = 'month'), '0 months ago')
+        assertEqual(later105.humanize(self.now, granularity = 'month'), 'in 0 months')
+        
+        later106 = self.now.shift(seconds=3 * 10 ** 6)
+        assertEqual(self.now.humanize(later106, granularity = 'day'), '34 days ago')
+        assertEqual(later106.humanize(self.now, granularity = 'day'), 'in 34 days')
+        assertEqual(self.now.humanize(later106, granularity = 'month'), 'a month ago')
+        assertEqual(later106.humanize(self.now, granularity = 'month'), 'in a month')
+        assertEqual(self.now.humanize(later106, granularity = 'year'), '0 years ago')
+        assertEqual(later106.humanize(self.now, granularity = 'year'), 'in 0 years')
+        
+        later506 = self.now.shift(seconds=50 * 10 ** 6)
+        assertEqual(self.now.humanize(later506, granularity = 'month'), '18 months ago')
+        assertEqual(later506.humanize(self.now, granularity = 'month'), 'in 18 months')
+        assertEqual(self.now.humanize(later506, granularity = 'year'), 'a year ago')
+        assertEqual(later506.humanize(self.now, granularity = 'year'), 'in a year')
+        
+        later108 = self.now.shift(seconds=10 ** 8)
+        assertEqual(self.now.humanize(later108, granularity = 'year'), '3 years ago')
+        assertEqual(later108.humanize(self.now, granularity = 'year'), 'in 3 years')
+        with assertRaises(AttributeError):
+            self.now.humanize(later108, granularity = 'years')
+    
     def test_seconds(self):
 
         later = self.now.shift(seconds=10)
